import PropTypes from "prop-types";
import Link from "next/link";
import cn from "classnames";
import styles from "./styles.module.css";

const Button = ({
  children,
  disabled = false,
  variant,
  className,
  href,
  ...props
}) => {
  const classNames = cn(styles["btn"], {
    [styles[variant]]: variant,
    [styles[className]]: className,
    [styles.disabled]: disabled,
  });

  return (
    <Link href={href} className={classNames} {...props}>
      {children}
    </Link>
  );
};

Button.propTypes = {
  variant: PropTypes.oneOf(["primary", "secondary"]),
  children: PropTypes.any,
  isDisabled: PropTypes.bool,
};

export default Button;
