import PropTypes from "prop-types";
import Card from "@components/base/card";
import Pagination from "@components/top-level/pagination";
import styles from "./styles.module.css";

const BlogLists = ({
  title,
  description,
  blogs,
  currentPage,
  total,
  search,
}) => {
  return (
    <div className={styles["blog-container"]}>
      <h2 className={styles.title}>{title}</h2>
      <p className={styles.description}>{description}</p>
      <div className={styles.row}>
        {blogs.map((blogData, i) => (
          <div key={i} className={styles.col}>
            <Card {...blogData} />
          </div>
        ))}
      </div>
      <div className={styles.pagination}>
        <Pagination
          currentPage={currentPage}
          total={Number(total)}
          perPage={6}
          search={search}
        />
      </div>
    </div>
  );
};

BlogLists.propTypes = {
  title: PropTypes.string,
  description: PropTypes.string,
  blogs: PropTypes.array,
  currentPage: PropTypes.number,
  total: PropTypes.number,
};

export default BlogLists;
